@@ -23,19 +23,17 @@
 #define __LIBXMLPP_EXCEPTION_H
 
 #include <exception>
-#include <string>
-
-#include <libxml++/api_export.h>
+#include <glibmm/ustring.h>
 
 namespace xmlpp
 {
 
 /** Base class for all xmlpp exceptions.
  */
-class LIBXMLPP_API exception: public std::exception
+class exception: public std::exception
 {
 public:
-  explicit exception(const std::string& message);
+  explicit exception(const Glib::ustring& message);
   virtual ~exception() throw();
 
   virtual const char* what() const throw();
@@ -43,7 +41,7 @@ public:
   virtual exception * Clone() const;
 
 private:
-  std::string message_;
+  Glib::ustring message_;
 };
 
 } // namespace xmlpp
